@@ -8,6 +8,28 @@
 #include "cpphelper.h"
 #include "typehelper.h"
 
+namespace
+{
+
+QString qualifiedName(const Node *node)
+{
+    if (node->type() == Node::Class) {
+        return static_cast<const ClassNode *>(node)->className();
+    }
+    if (node->type() == Node::Enum) {
+        auto enumNode = static_cast<const EnumNode *>(node);
+        if (enumNode->enumType() == EnumNode::TypeFlag) {
+            return QStringLiteral("%1::%2").arg(qualifiedName(node->parent()), enumNode->flagsName());
+        }
+        return QStringLiteral("%1::%2").arg(qualifiedName(node->parent()), enumNode->name());
+    }
+
+    Q_ASSERT_X(false, "qualifiedName", "Invalid node type");
+    return {};
+}
+
+} // namespace
+
 Node::Node(NodeType type, Node *parent)
     : mParent(parent)
     , mType(type)
@@ -108,13 +130,13 @@ QString ClassNode::parentClassName() const
 
 ClassNode::ClassType ClassNode::elementNameToType(QStringView name)
 {
-    if (name == QLatin1String("class")) {
+    if (name == QLatin1StringView("class")) {
         return Class;
-    } else if (name == QLatin1String("command")) {
+    } else if (name == QLatin1StringView("command")) {
         return Command;
-    } else if (name == QLatin1String("response")) {
+    } else if (name == QLatin1StringView("response")) {
         return Response;
-    } else if (name == QLatin1String("notification")) {
+    } else if (name == QLatin1StringView("notification")) {
         return Notification;
     } else {
         return Invalid;
@@ -174,11 +196,21 @@ EnumNode::EnumType EnumNode::enumType() const
 {
     return mEnumType;
 }
+
+QString EnumNode::flagsName() const
+{
+    if (mEnumType == TypeFlag) {
+        return mName + QStringLiteral("s");
+    }
+
+    return {};
+}
+
 EnumNode::EnumType EnumNode::elementNameToType(QStringView name)
 {
-    if (name == QLatin1String("enum")) {
+    if (name == QLatin1StringView("enum")) {
         return TypeEnum;
-    } else if (name == QLatin1String("flag")) {
+    } else if (name == QLatin1StringView("flag")) {
         return TypeFlag;
     } else {
         return TypeInvalid;
@@ -267,6 +299,21 @@ bool PropertyNode::isPointer() const
     return TypeHelper::isPointerType(mType);
 }
 
+bool PropertyNode::isEnum() const
+{
+    auto parentClass = static_cast<ClassNode *>(parent());
+    for (const auto node : parentClass->children()) {
+        if (node->type() == Node::Enum) {
+            const auto enumNode = static_cast<const EnumNode *>(node);
+            if (qualifiedName(enumNode) == mType) {
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+
 QMultiMap<QString, QString> PropertyNode::dependencies() const
 {
     return mDepends;
