@@ -7,6 +7,7 @@
 #include "standardactionmanager.h"
 
 #include "actionstatemanager_p.h"
+#include "agentconfigurationdialog.h"
 #include "agentfilterproxymodel.h"
 #include "agentinstancecreatejob.h"
 #include "agentmanager.h"
@@ -1352,10 +1353,19 @@ public:
 
             if (agentType.isValid()) {
                 auto job = new AgentInstanceCreateJob(agentType, q);
-                q->connect(job, &KJob::result, q, [this](KJob *job) {
-                    resourceCreationResult(job);
+                q->connect(job, &KJob::result, q, [this, job](KJob *) {
+                    if (job->error()) {
+                        resourceCreationResult(job);
+                        return;
+                    }
+
+                    auto configureDialog = new Akonadi::AgentConfigurationDialog(job->instance(), parentWidget);
+                    configureDialog->setAttribute(Qt::WA_DeleteOnClose);
+                    q->connect(configureDialog, &QDialog::rejected, q, [instance = job->instance()] {
+                        Akonadi::AgentManager::self()->removeInstance(instance);
+                    });
+                    configureDialog->show();
                 });
-                job->configure(parentWidget);
                 job->start();
             }
         }
@@ -1409,7 +1419,9 @@ public:
             return;
         }
 
-        instance.configure(parentWidget);
+        auto configureDialog = new Akonadi::AgentConfigurationDialog(instance, parentWidget);
+        configureDialog->setAttribute(Qt::WA_DeleteOnClose);
+        configureDialog->show();
     }
 
     void slotToggleWorkOffline(bool offline)
@@ -1708,7 +1720,7 @@ public:
             return;
         }
 
-        const QByteArray cutSelectionData = "1"; // krazy:exclude=doublequote_chars
+        const QByteArray cutSelectionData = "1";
         mimeData->setData(QStringLiteral("application/x-kde.akonadi-cutselection"), cutSelectionData);
     }
 
